# pydownloadfile
*Python3 module to download files using requests.*

## Installation
### Install with pip
```
pip3 install -U pydownloadfile
```

## Usage
```
In [1]: import pydownloadfile

In [4]: pydownloadfile.download_file(
    url="https://...",
    filename="foobar..."
    headers=None
    proxies=None
    )
```
